schema

package
v0.0.0-...-b708652 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2024 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	Order = iota
)

Variables

This section is empty.

Functions

func BaseTable

func BaseTable() []ent.Field

Types

type Account

type Account struct {
	ent.Schema
}

Account holds the schema definition for the Account entity.

func (Account) Edges

func (Account) Edges() []ent.Edge

Edges of the Account.

func (Account) Fields

func (Account) Fields() []ent.Field

Fields of the Account. user sets their own user data here, if we have data from this table we won't be looking for users table because those coming from discord. This account table is supposed to override user table

type Links struct {
	ent.Schema
}

Links holds the schema definition for the Links entity.

func (Links) Edges

func (Links) Edges() []ent.Edge

Edges of the Links.

func (Links) Fields

func (Links) Fields() []ent.Field

Fields of the Links.

func (Links) Index

func (Links) Index() []ent.Index

type Session

type Session struct {
	ent.Schema
}

Session holds the schema definition for the Session entity.

func (Session) Edges

func (Session) Edges() []ent.Edge

Edges of the Session.

func (Session) Fields

func (Session) Fields() []ent.Field

Fields of the Session.

type Users

type Users struct {
	ent.Schema
}

Users holds the schema definition for the Users entity.

func (Users) Edges

func (Users) Edges() []ent.Edge

Edges of the Users.

func (Users) Fields

func (Users) Fields() []ent.Field

Fields of the Users coming from providers

Jump to