users

package
v0.0.0-...-b708652 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2024 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the users type in the database.
	Label = "users"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldExternalID holds the string denoting the external_id field in the database.
	FieldExternalID = "external_id"
	// FieldUsername holds the string denoting the username field in the database.
	FieldUsername = "username"
	// FieldGlobalName holds the string denoting the global_name field in the database.
	FieldGlobalName = "global_name"
	// FieldSlug holds the string denoting the slug field in the database.
	FieldSlug = "slug"
	// FieldAvatar holds the string denoting the avatar field in the database.
	FieldAvatar = "avatar"
	// FieldDescription holds the string denoting the description field in the database.
	FieldDescription = "description"
	// FieldAccessToken holds the string denoting the access_token field in the database.
	FieldAccessToken = "access_token"
	// FieldRefreshToken holds the string denoting the refresh_token field in the database.
	FieldRefreshToken = "refresh_token"
	// FieldScope holds the string denoting the scope field in the database.
	FieldScope = "scope"
	// FieldExpiresIn holds the string denoting the expires_in field in the database.
	FieldExpiresIn = "expires_in"
	// FieldSessionState holds the string denoting the session_state field in the database.
	FieldSessionState = "session_state"
	// FieldDeleted holds the string denoting the deleted field in the database.
	FieldDeleted = "deleted"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// EdgeUsersLinks holds the string denoting the users_links edge name in mutations.
	EdgeUsersLinks = "users_links"
	// EdgeUsersSessions holds the string denoting the users_sessions edge name in mutations.
	EdgeUsersSessions = "users_sessions"
	// EdgeUsersAccounts holds the string denoting the users_accounts edge name in mutations.
	EdgeUsersAccounts = "users_accounts"
	// Table holds the table name of the users in the database.
	Table = "users"
	// UsersLinksTable is the table that holds the users_links relation/edge.
	UsersLinksTable = "links"
	// UsersLinksInverseTable is the table name for the Links entity.
	// It exists in this package in order to avoid circular dependency with the "links" package.
	UsersLinksInverseTable = "links"
	// UsersLinksColumn is the table column denoting the users_links relation/edge.
	UsersLinksColumn = "user_id"
	// UsersSessionsTable is the table that holds the users_sessions relation/edge.
	UsersSessionsTable = "sessions"
	// UsersSessionsInverseTable is the table name for the Session entity.
	// It exists in this package in order to avoid circular dependency with the "session" package.
	UsersSessionsInverseTable = "sessions"
	// UsersSessionsColumn is the table column denoting the users_sessions relation/edge.
	UsersSessionsColumn = "user_id"
	// UsersAccountsTable is the table that holds the users_accounts relation/edge.
	UsersAccountsTable = "accounts"
	// UsersAccountsInverseTable is the table name for the Account entity.
	// It exists in this package in order to avoid circular dependency with the "account" package.
	UsersAccountsInverseTable = "accounts"
	// UsersAccountsColumn is the table column denoting the users_accounts relation/edge.
	UsersAccountsColumn = "external_id"
)

Variables

var (
	// UsernameValidator is a validator for the "username" field. It is called by the builders before save.
	UsernameValidator func(string) error
	// GlobalNameValidator is a validator for the "global_name" field. It is called by the builders before save.
	GlobalNameValidator func(string) error
	// SlugValidator is a validator for the "slug" field. It is called by the builders before save.
	SlugValidator func(string) error
	// AvatarValidator is a validator for the "avatar" field. It is called by the builders before save.
	AvatarValidator func(string) error
	// DescriptionValidator is a validator for the "description" field. It is called by the builders before save.
	DescriptionValidator func(string) error
	// AccessTokenValidator is a validator for the "access_token" field. It is called by the builders before save.
	AccessTokenValidator func(string) error
	// RefreshTokenValidator is a validator for the "refresh_token" field. It is called by the builders before save.
	RefreshTokenValidator func(string) error
	// ScopeValidator is a validator for the "scope" field. It is called by the builders before save.
	ScopeValidator func(string) error
	// DefaultDeleted holds the default value on creation for the "deleted" field.
	DefaultDeleted bool
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for users fields.

Functions

func AccessToken

func AccessToken(v string) predicate.Users

AccessToken applies equality check predicate on the "access_token" field. It's identical to AccessTokenEQ.

func AccessTokenContains

func AccessTokenContains(v string) predicate.Users

AccessTokenContains applies the Contains predicate on the "access_token" field.

func AccessTokenContainsFold

func AccessTokenContainsFold(v string) predicate.Users

AccessTokenContainsFold applies the ContainsFold predicate on the "access_token" field.

func AccessTokenEQ

func AccessTokenEQ(v string) predicate.Users

AccessTokenEQ applies the EQ predicate on the "access_token" field.

func AccessTokenEqualFold

func AccessTokenEqualFold(v string) predicate.Users

AccessTokenEqualFold applies the EqualFold predicate on the "access_token" field.

func AccessTokenGT

func AccessTokenGT(v string) predicate.Users

AccessTokenGT applies the GT predicate on the "access_token" field.

func AccessTokenGTE

func AccessTokenGTE(v string) predicate.Users

AccessTokenGTE applies the GTE predicate on the "access_token" field.

func AccessTokenHasPrefix

func AccessTokenHasPrefix(v string) predicate.Users

AccessTokenHasPrefix applies the HasPrefix predicate on the "access_token" field.

func AccessTokenHasSuffix

func AccessTokenHasSuffix(v string) predicate.Users

AccessTokenHasSuffix applies the HasSuffix predicate on the "access_token" field.

func AccessTokenIn

func AccessTokenIn(vs ...string) predicate.Users

AccessTokenIn applies the In predicate on the "access_token" field.

func AccessTokenIsNil

func AccessTokenIsNil() predicate.Users

AccessTokenIsNil applies the IsNil predicate on the "access_token" field.

func AccessTokenLT

func AccessTokenLT(v string) predicate.Users

AccessTokenLT applies the LT predicate on the "access_token" field.

func AccessTokenLTE

func AccessTokenLTE(v string) predicate.Users

AccessTokenLTE applies the LTE predicate on the "access_token" field.

func AccessTokenNEQ

func AccessTokenNEQ(v string) predicate.Users

AccessTokenNEQ applies the NEQ predicate on the "access_token" field.

func AccessTokenNotIn

func AccessTokenNotIn(vs ...string) predicate.Users

AccessTokenNotIn applies the NotIn predicate on the "access_token" field.

func AccessTokenNotNil

func AccessTokenNotNil() predicate.Users

AccessTokenNotNil applies the NotNil predicate on the "access_token" field.

func And

func And(predicates ...predicate.Users) predicate.Users

And groups predicates with the AND operator between them.

func Avatar

func Avatar(v string) predicate.Users

Avatar applies equality check predicate on the "avatar" field. It's identical to AvatarEQ.

func AvatarContains

func AvatarContains(v string) predicate.Users

AvatarContains applies the Contains predicate on the "avatar" field.

func AvatarContainsFold

func AvatarContainsFold(v string) predicate.Users

AvatarContainsFold applies the ContainsFold predicate on the "avatar" field.

func AvatarEQ

func AvatarEQ(v string) predicate.Users

AvatarEQ applies the EQ predicate on the "avatar" field.

func AvatarEqualFold

func AvatarEqualFold(v string) predicate.Users

AvatarEqualFold applies the EqualFold predicate on the "avatar" field.

func AvatarGT

func AvatarGT(v string) predicate.Users

AvatarGT applies the GT predicate on the "avatar" field.

func AvatarGTE

func AvatarGTE(v string) predicate.Users

AvatarGTE applies the GTE predicate on the "avatar" field.

func AvatarHasPrefix

func AvatarHasPrefix(v string) predicate.Users

AvatarHasPrefix applies the HasPrefix predicate on the "avatar" field.

func AvatarHasSuffix

func AvatarHasSuffix(v string) predicate.Users

AvatarHasSuffix applies the HasSuffix predicate on the "avatar" field.

func AvatarIn

func AvatarIn(vs ...string) predicate.Users

AvatarIn applies the In predicate on the "avatar" field.

func AvatarIsNil

func AvatarIsNil() predicate.Users

AvatarIsNil applies the IsNil predicate on the "avatar" field.

func AvatarLT

func AvatarLT(v string) predicate.Users

AvatarLT applies the LT predicate on the "avatar" field.

func AvatarLTE

func AvatarLTE(v string) predicate.Users

AvatarLTE applies the LTE predicate on the "avatar" field.

func AvatarNEQ

func AvatarNEQ(v string) predicate.Users

AvatarNEQ applies the NEQ predicate on the "avatar" field.

func AvatarNotIn

func AvatarNotIn(vs ...string) predicate.Users

AvatarNotIn applies the NotIn predicate on the "avatar" field.

func AvatarNotNil

func AvatarNotNil() predicate.Users

AvatarNotNil applies the NotNil predicate on the "avatar" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Users

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Users

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Users

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Users

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Users

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Users

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Users

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Users

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Users

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Deleted

func Deleted(v bool) predicate.Users

Deleted applies equality check predicate on the "deleted" field. It's identical to DeletedEQ.

func DeletedEQ

func DeletedEQ(v bool) predicate.Users

DeletedEQ applies the EQ predicate on the "deleted" field.

func DeletedNEQ

func DeletedNEQ(v bool) predicate.Users

DeletedNEQ applies the NEQ predicate on the "deleted" field.

func Description

func Description(v string) predicate.Users

Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.

func DescriptionContains

func DescriptionContains(v string) predicate.Users

DescriptionContains applies the Contains predicate on the "description" field.

func DescriptionContainsFold

func DescriptionContainsFold(v string) predicate.Users

DescriptionContainsFold applies the ContainsFold predicate on the "description" field.

func DescriptionEQ

func DescriptionEQ(v string) predicate.Users

DescriptionEQ applies the EQ predicate on the "description" field.

func DescriptionEqualFold

func DescriptionEqualFold(v string) predicate.Users

DescriptionEqualFold applies the EqualFold predicate on the "description" field.

func DescriptionGT

func DescriptionGT(v string) predicate.Users

DescriptionGT applies the GT predicate on the "description" field.

func DescriptionGTE

func DescriptionGTE(v string) predicate.Users

DescriptionGTE applies the GTE predicate on the "description" field.

func DescriptionHasPrefix

func DescriptionHasPrefix(v string) predicate.Users

DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.

func DescriptionHasSuffix

func DescriptionHasSuffix(v string) predicate.Users

DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.

func DescriptionIn

func DescriptionIn(vs ...string) predicate.Users

DescriptionIn applies the In predicate on the "description" field.

func DescriptionIsNil

func DescriptionIsNil() predicate.Users

DescriptionIsNil applies the IsNil predicate on the "description" field.

func DescriptionLT

func DescriptionLT(v string) predicate.Users

DescriptionLT applies the LT predicate on the "description" field.

func DescriptionLTE

func DescriptionLTE(v string) predicate.Users

DescriptionLTE applies the LTE predicate on the "description" field.

func DescriptionNEQ

func DescriptionNEQ(v string) predicate.Users

DescriptionNEQ applies the NEQ predicate on the "description" field.

func DescriptionNotIn

func DescriptionNotIn(vs ...string) predicate.Users

DescriptionNotIn applies the NotIn predicate on the "description" field.

func DescriptionNotNil

func DescriptionNotNil() predicate.Users

DescriptionNotNil applies the NotNil predicate on the "description" field.

func ExpiresIn

func ExpiresIn(v float64) predicate.Users

ExpiresIn applies equality check predicate on the "expires_in" field. It's identical to ExpiresInEQ.

func ExpiresInEQ

func ExpiresInEQ(v float64) predicate.Users

ExpiresInEQ applies the EQ predicate on the "expires_in" field.

func ExpiresInGT

func ExpiresInGT(v float64) predicate.Users

ExpiresInGT applies the GT predicate on the "expires_in" field.

func ExpiresInGTE

func ExpiresInGTE(v float64) predicate.Users

ExpiresInGTE applies the GTE predicate on the "expires_in" field.

func ExpiresInIn

func ExpiresInIn(vs ...float64) predicate.Users

ExpiresInIn applies the In predicate on the "expires_in" field.

func ExpiresInIsNil

func ExpiresInIsNil() predicate.Users

ExpiresInIsNil applies the IsNil predicate on the "expires_in" field.

func ExpiresInLT

func ExpiresInLT(v float64) predicate.Users

ExpiresInLT applies the LT predicate on the "expires_in" field.

func ExpiresInLTE

func ExpiresInLTE(v float64) predicate.Users

ExpiresInLTE applies the LTE predicate on the "expires_in" field.

func ExpiresInNEQ

func ExpiresInNEQ(v float64) predicate.Users

ExpiresInNEQ applies the NEQ predicate on the "expires_in" field.

func ExpiresInNotIn

func ExpiresInNotIn(vs ...float64) predicate.Users

ExpiresInNotIn applies the NotIn predicate on the "expires_in" field.

func ExpiresInNotNil

func ExpiresInNotNil() predicate.Users

ExpiresInNotNil applies the NotNil predicate on the "expires_in" field.

func ExternalID

func ExternalID(v string) predicate.Users

ExternalID applies equality check predicate on the "external_id" field. It's identical to ExternalIDEQ.

func ExternalIDContains

func ExternalIDContains(v string) predicate.Users

ExternalIDContains applies the Contains predicate on the "external_id" field.

func ExternalIDContainsFold

func ExternalIDContainsFold(v string) predicate.Users

ExternalIDContainsFold applies the ContainsFold predicate on the "external_id" field.

func ExternalIDEQ

func ExternalIDEQ(v string) predicate.Users

ExternalIDEQ applies the EQ predicate on the "external_id" field.

func ExternalIDEqualFold

func ExternalIDEqualFold(v string) predicate.Users

ExternalIDEqualFold applies the EqualFold predicate on the "external_id" field.

func ExternalIDGT

func ExternalIDGT(v string) predicate.Users

ExternalIDGT applies the GT predicate on the "external_id" field.

func ExternalIDGTE

func ExternalIDGTE(v string) predicate.Users

ExternalIDGTE applies the GTE predicate on the "external_id" field.

func ExternalIDHasPrefix

func ExternalIDHasPrefix(v string) predicate.Users

ExternalIDHasPrefix applies the HasPrefix predicate on the "external_id" field.

func ExternalIDHasSuffix

func ExternalIDHasSuffix(v string) predicate.Users

ExternalIDHasSuffix applies the HasSuffix predicate on the "external_id" field.

func ExternalIDIn

func ExternalIDIn(vs ...string) predicate.Users

ExternalIDIn applies the In predicate on the "external_id" field.

func ExternalIDLT

func ExternalIDLT(v string) predicate.Users

ExternalIDLT applies the LT predicate on the "external_id" field.

func ExternalIDLTE

func ExternalIDLTE(v string) predicate.Users

ExternalIDLTE applies the LTE predicate on the "external_id" field.

func ExternalIDNEQ

func ExternalIDNEQ(v string) predicate.Users

ExternalIDNEQ applies the NEQ predicate on the "external_id" field.

func ExternalIDNotIn

func ExternalIDNotIn(vs ...string) predicate.Users

ExternalIDNotIn applies the NotIn predicate on the "external_id" field.

func GlobalName

func GlobalName(v string) predicate.Users

GlobalName applies equality check predicate on the "global_name" field. It's identical to GlobalNameEQ.

func GlobalNameContains

func GlobalNameContains(v string) predicate.Users

GlobalNameContains applies the Contains predicate on the "global_name" field.

func GlobalNameContainsFold

func GlobalNameContainsFold(v string) predicate.Users

GlobalNameContainsFold applies the ContainsFold predicate on the "global_name" field.

func GlobalNameEQ

func GlobalNameEQ(v string) predicate.Users

GlobalNameEQ applies the EQ predicate on the "global_name" field.

func GlobalNameEqualFold

func GlobalNameEqualFold(v string) predicate.Users

GlobalNameEqualFold applies the EqualFold predicate on the "global_name" field.

func GlobalNameGT

func GlobalNameGT(v string) predicate.Users

GlobalNameGT applies the GT predicate on the "global_name" field.

func GlobalNameGTE

func GlobalNameGTE(v string) predicate.Users

GlobalNameGTE applies the GTE predicate on the "global_name" field.

func GlobalNameHasPrefix

func GlobalNameHasPrefix(v string) predicate.Users

GlobalNameHasPrefix applies the HasPrefix predicate on the "global_name" field.

func GlobalNameHasSuffix

func GlobalNameHasSuffix(v string) predicate.Users

GlobalNameHasSuffix applies the HasSuffix predicate on the "global_name" field.

func GlobalNameIn

func GlobalNameIn(vs ...string) predicate.Users

GlobalNameIn applies the In predicate on the "global_name" field.

func GlobalNameLT

func GlobalNameLT(v string) predicate.Users

GlobalNameLT applies the LT predicate on the "global_name" field.

func GlobalNameLTE

func GlobalNameLTE(v string) predicate.Users

GlobalNameLTE applies the LTE predicate on the "global_name" field.

func GlobalNameNEQ

func GlobalNameNEQ(v string) predicate.Users

GlobalNameNEQ applies the NEQ predicate on the "global_name" field.

func GlobalNameNotIn

func GlobalNameNotIn(vs ...string) predicate.Users

GlobalNameNotIn applies the NotIn predicate on the "global_name" field.

func HasUsersAccounts

func HasUsersAccounts() predicate.Users

HasUsersAccounts applies the HasEdge predicate on the "users_accounts" edge.

func HasUsersAccountsWith

func HasUsersAccountsWith(preds ...predicate.Account) predicate.Users

HasUsersAccountsWith applies the HasEdge predicate on the "users_accounts" edge with a given conditions (other predicates).

func HasUsersLinks() predicate.Users

HasUsersLinks applies the HasEdge predicate on the "users_links" edge.

func HasUsersLinksWith

func HasUsersLinksWith(preds ...predicate.Links) predicate.Users

HasUsersLinksWith applies the HasEdge predicate on the "users_links" edge with a given conditions (other predicates).

func HasUsersSessions

func HasUsersSessions() predicate.Users

HasUsersSessions applies the HasEdge predicate on the "users_sessions" edge.

func HasUsersSessionsWith

func HasUsersSessionsWith(preds ...predicate.Session) predicate.Users

HasUsersSessionsWith applies the HasEdge predicate on the "users_sessions" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Users

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Users

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Users

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Users

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Users

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Users

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Users

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Users

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Users

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Users) predicate.Users

Or groups predicates with the OR operator between them.

func RefreshToken

func RefreshToken(v string) predicate.Users

RefreshToken applies equality check predicate on the "refresh_token" field. It's identical to RefreshTokenEQ.

func RefreshTokenContains

func RefreshTokenContains(v string) predicate.Users

RefreshTokenContains applies the Contains predicate on the "refresh_token" field.

func RefreshTokenContainsFold

func RefreshTokenContainsFold(v string) predicate.Users

RefreshTokenContainsFold applies the ContainsFold predicate on the "refresh_token" field.

func RefreshTokenEQ

func RefreshTokenEQ(v string) predicate.Users

RefreshTokenEQ applies the EQ predicate on the "refresh_token" field.

func RefreshTokenEqualFold

func RefreshTokenEqualFold(v string) predicate.Users

RefreshTokenEqualFold applies the EqualFold predicate on the "refresh_token" field.

func RefreshTokenGT

func RefreshTokenGT(v string) predicate.Users

RefreshTokenGT applies the GT predicate on the "refresh_token" field.

func RefreshTokenGTE

func RefreshTokenGTE(v string) predicate.Users

RefreshTokenGTE applies the GTE predicate on the "refresh_token" field.

func RefreshTokenHasPrefix

func RefreshTokenHasPrefix(v string) predicate.Users

RefreshTokenHasPrefix applies the HasPrefix predicate on the "refresh_token" field.

func RefreshTokenHasSuffix

func RefreshTokenHasSuffix(v string) predicate.Users

RefreshTokenHasSuffix applies the HasSuffix predicate on the "refresh_token" field.

func RefreshTokenIn

func RefreshTokenIn(vs ...string) predicate.Users

RefreshTokenIn applies the In predicate on the "refresh_token" field.

func RefreshTokenIsNil

func RefreshTokenIsNil() predicate.Users

RefreshTokenIsNil applies the IsNil predicate on the "refresh_token" field.

func RefreshTokenLT

func RefreshTokenLT(v string) predicate.Users

RefreshTokenLT applies the LT predicate on the "refresh_token" field.

func RefreshTokenLTE

func RefreshTokenLTE(v string) predicate.Users

RefreshTokenLTE applies the LTE predicate on the "refresh_token" field.

func RefreshTokenNEQ

func RefreshTokenNEQ(v string) predicate.Users

RefreshTokenNEQ applies the NEQ predicate on the "refresh_token" field.

func RefreshTokenNotIn

func RefreshTokenNotIn(vs ...string) predicate.Users

RefreshTokenNotIn applies the NotIn predicate on the "refresh_token" field.

func RefreshTokenNotNil

func RefreshTokenNotNil() predicate.Users

RefreshTokenNotNil applies the NotNil predicate on the "refresh_token" field.

func Scope

func Scope(v string) predicate.Users

Scope applies equality check predicate on the "scope" field. It's identical to ScopeEQ.

func ScopeContains

func ScopeContains(v string) predicate.Users

ScopeContains applies the Contains predicate on the "scope" field.

func ScopeContainsFold

func ScopeContainsFold(v string) predicate.Users

ScopeContainsFold applies the ContainsFold predicate on the "scope" field.

func ScopeEQ

func ScopeEQ(v string) predicate.Users

ScopeEQ applies the EQ predicate on the "scope" field.

func ScopeEqualFold

func ScopeEqualFold(v string) predicate.Users

ScopeEqualFold applies the EqualFold predicate on the "scope" field.

func ScopeGT

func ScopeGT(v string) predicate.Users

ScopeGT applies the GT predicate on the "scope" field.

func ScopeGTE

func ScopeGTE(v string) predicate.Users

ScopeGTE applies the GTE predicate on the "scope" field.

func ScopeHasPrefix

func ScopeHasPrefix(v string) predicate.Users

ScopeHasPrefix applies the HasPrefix predicate on the "scope" field.

func ScopeHasSuffix

func ScopeHasSuffix(v string) predicate.Users

ScopeHasSuffix applies the HasSuffix predicate on the "scope" field.

func ScopeIn

func ScopeIn(vs ...string) predicate.Users

ScopeIn applies the In predicate on the "scope" field.

func ScopeIsNil

func ScopeIsNil() predicate.Users

ScopeIsNil applies the IsNil predicate on the "scope" field.

func ScopeLT

func ScopeLT(v string) predicate.Users

ScopeLT applies the LT predicate on the "scope" field.

func ScopeLTE

func ScopeLTE(v string) predicate.Users

ScopeLTE applies the LTE predicate on the "scope" field.

func ScopeNEQ

func ScopeNEQ(v string) predicate.Users

ScopeNEQ applies the NEQ predicate on the "scope" field.

func ScopeNotIn

func ScopeNotIn(vs ...string) predicate.Users

ScopeNotIn applies the NotIn predicate on the "scope" field.

func ScopeNotNil

func ScopeNotNil() predicate.Users

ScopeNotNil applies the NotNil predicate on the "scope" field.

func SessionState

func SessionState(v string) predicate.Users

SessionState applies equality check predicate on the "session_state" field. It's identical to SessionStateEQ.

func SessionStateContains

func SessionStateContains(v string) predicate.Users

SessionStateContains applies the Contains predicate on the "session_state" field.

func SessionStateContainsFold

func SessionStateContainsFold(v string) predicate.Users

SessionStateContainsFold applies the ContainsFold predicate on the "session_state" field.

func SessionStateEQ

func SessionStateEQ(v string) predicate.Users

SessionStateEQ applies the EQ predicate on the "session_state" field.

func SessionStateEqualFold

func SessionStateEqualFold(v string) predicate.Users

SessionStateEqualFold applies the EqualFold predicate on the "session_state" field.

func SessionStateGT

func SessionStateGT(v string) predicate.Users

SessionStateGT applies the GT predicate on the "session_state" field.

func SessionStateGTE

func SessionStateGTE(v string) predicate.Users

SessionStateGTE applies the GTE predicate on the "session_state" field.

func SessionStateHasPrefix

func SessionStateHasPrefix(v string) predicate.Users

SessionStateHasPrefix applies the HasPrefix predicate on the "session_state" field.

func SessionStateHasSuffix

func SessionStateHasSuffix(v string) predicate.Users

SessionStateHasSuffix applies the HasSuffix predicate on the "session_state" field.

func SessionStateIn

func SessionStateIn(vs ...string) predicate.Users

SessionStateIn applies the In predicate on the "session_state" field.

func SessionStateIsNil

func SessionStateIsNil() predicate.Users

SessionStateIsNil applies the IsNil predicate on the "session_state" field.

func SessionStateLT

func SessionStateLT(v string) predicate.Users

SessionStateLT applies the LT predicate on the "session_state" field.

func SessionStateLTE

func SessionStateLTE(v string) predicate.Users

SessionStateLTE applies the LTE predicate on the "session_state" field.

func SessionStateNEQ

func SessionStateNEQ(v string) predicate.Users

SessionStateNEQ applies the NEQ predicate on the "session_state" field.

func SessionStateNotIn

func SessionStateNotIn(vs ...string) predicate.Users

SessionStateNotIn applies the NotIn predicate on the "session_state" field.

func SessionStateNotNil

func SessionStateNotNil() predicate.Users

SessionStateNotNil applies the NotNil predicate on the "session_state" field.

func Slug

func Slug(v string) predicate.Users

Slug applies equality check predicate on the "slug" field. It's identical to SlugEQ.

func SlugContains

func SlugContains(v string) predicate.Users

SlugContains applies the Contains predicate on the "slug" field.

func SlugContainsFold

func SlugContainsFold(v string) predicate.Users

SlugContainsFold applies the ContainsFold predicate on the "slug" field.

func SlugEQ

func SlugEQ(v string) predicate.Users

SlugEQ applies the EQ predicate on the "slug" field.

func SlugEqualFold

func SlugEqualFold(v string) predicate.Users

SlugEqualFold applies the EqualFold predicate on the "slug" field.

func SlugGT

func SlugGT(v string) predicate.Users

SlugGT applies the GT predicate on the "slug" field.

func SlugGTE

func SlugGTE(v string) predicate.Users

SlugGTE applies the GTE predicate on the "slug" field.

func SlugHasPrefix

func SlugHasPrefix(v string) predicate.Users

SlugHasPrefix applies the HasPrefix predicate on the "slug" field.

func SlugHasSuffix

func SlugHasSuffix(v string) predicate.Users

SlugHasSuffix applies the HasSuffix predicate on the "slug" field.

func SlugIn

func SlugIn(vs ...string) predicate.Users

SlugIn applies the In predicate on the "slug" field.

func SlugLT

func SlugLT(v string) predicate.Users

SlugLT applies the LT predicate on the "slug" field.

func SlugLTE

func SlugLTE(v string) predicate.Users

SlugLTE applies the LTE predicate on the "slug" field.

func SlugNEQ

func SlugNEQ(v string) predicate.Users

SlugNEQ applies the NEQ predicate on the "slug" field.

func SlugNotIn

func SlugNotIn(vs ...string) predicate.Users

SlugNotIn applies the NotIn predicate on the "slug" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Users

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Users

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Users

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Users

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Users

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Users

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Users

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Users

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Users

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func Username

func Username(v string) predicate.Users

Username applies equality check predicate on the "username" field. It's identical to UsernameEQ.

func UsernameContains

func UsernameContains(v string) predicate.Users

UsernameContains applies the Contains predicate on the "username" field.

func UsernameContainsFold

func UsernameContainsFold(v string) predicate.Users

UsernameContainsFold applies the ContainsFold predicate on the "username" field.

func UsernameEQ

func UsernameEQ(v string) predicate.Users

UsernameEQ applies the EQ predicate on the "username" field.

func UsernameEqualFold

func UsernameEqualFold(v string) predicate.Users

UsernameEqualFold applies the EqualFold predicate on the "username" field.

func UsernameGT

func UsernameGT(v string) predicate.Users

UsernameGT applies the GT predicate on the "username" field.

func UsernameGTE

func UsernameGTE(v string) predicate.Users

UsernameGTE applies the GTE predicate on the "username" field.

func UsernameHasPrefix

func UsernameHasPrefix(v string) predicate.Users

UsernameHasPrefix applies the HasPrefix predicate on the "username" field.

func UsernameHasSuffix

func UsernameHasSuffix(v string) predicate.Users

UsernameHasSuffix applies the HasSuffix predicate on the "username" field.

func UsernameIn

func UsernameIn(vs ...string) predicate.Users

UsernameIn applies the In predicate on the "username" field.

func UsernameLT

func UsernameLT(v string) predicate.Users

UsernameLT applies the LT predicate on the "username" field.

func UsernameLTE

func UsernameLTE(v string) predicate.Users

UsernameLTE applies the LTE predicate on the "username" field.

func UsernameNEQ

func UsernameNEQ(v string) predicate.Users

UsernameNEQ applies the NEQ predicate on the "username" field.

func UsernameNotIn

func UsernameNotIn(vs ...string) predicate.Users

UsernameNotIn applies the NotIn predicate on the "username" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Users queries.

func ByAccessToken

func ByAccessToken(opts ...sql.OrderTermOption) OrderOption

ByAccessToken orders the results by the access_token field.

func ByAvatar

func ByAvatar(opts ...sql.OrderTermOption) OrderOption

ByAvatar orders the results by the avatar field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDeleted

func ByDeleted(opts ...sql.OrderTermOption) OrderOption

ByDeleted orders the results by the deleted field.

func ByDescription

func ByDescription(opts ...sql.OrderTermOption) OrderOption

ByDescription orders the results by the description field.

func ByExpiresIn

func ByExpiresIn(opts ...sql.OrderTermOption) OrderOption

ByExpiresIn orders the results by the expires_in field.

func ByExternalID

func ByExternalID(opts ...sql.OrderTermOption) OrderOption

ByExternalID orders the results by the external_id field.

func ByGlobalName

func ByGlobalName(opts ...sql.OrderTermOption) OrderOption

ByGlobalName orders the results by the global_name field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByRefreshToken

func ByRefreshToken(opts ...sql.OrderTermOption) OrderOption

ByRefreshToken orders the results by the refresh_token field.

func ByScope

func ByScope(opts ...sql.OrderTermOption) OrderOption

ByScope orders the results by the scope field.

func BySessionState

func BySessionState(opts ...sql.OrderTermOption) OrderOption

BySessionState orders the results by the session_state field.

func BySlug

func BySlug(opts ...sql.OrderTermOption) OrderOption

BySlug orders the results by the slug field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUsername

func ByUsername(opts ...sql.OrderTermOption) OrderOption

ByUsername orders the results by the username field.

func ByUsersAccounts

func ByUsersAccounts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByUsersAccounts orders the results by users_accounts terms.

func ByUsersAccountsCount

func ByUsersAccountsCount(opts ...sql.OrderTermOption) OrderOption

ByUsersAccountsCount orders the results by users_accounts count.

func ByUsersLinks(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByUsersLinks orders the results by users_links terms.

func ByUsersLinksCount

func ByUsersLinksCount(opts ...sql.OrderTermOption) OrderOption

ByUsersLinksCount orders the results by users_links count.

func ByUsersSessions

func ByUsersSessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByUsersSessions orders the results by users_sessions terms.

func ByUsersSessionsCount

func ByUsersSessionsCount(opts ...sql.OrderTermOption) OrderOption

ByUsersSessionsCount orders the results by users_sessions count.

Jump to