Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Session) predicate.Session
- func CreatedAt(v time.Time) predicate.Session
- func CreatedAtEQ(v time.Time) predicate.Session
- func CreatedAtGT(v time.Time) predicate.Session
- func CreatedAtGTE(v time.Time) predicate.Session
- func CreatedAtIn(vs ...time.Time) predicate.Session
- func CreatedAtLT(v time.Time) predicate.Session
- func CreatedAtLTE(v time.Time) predicate.Session
- func CreatedAtNEQ(v time.Time) predicate.Session
- func CreatedAtNotIn(vs ...time.Time) predicate.Session
- func Deleted(v bool) predicate.Session
- func DeletedEQ(v bool) predicate.Session
- func DeletedNEQ(v bool) predicate.Session
- func ExpiresAt(v time.Time) predicate.Session
- func ExpiresAtEQ(v time.Time) predicate.Session
- func ExpiresAtGT(v time.Time) predicate.Session
- func ExpiresAtGTE(v time.Time) predicate.Session
- func ExpiresAtIn(vs ...time.Time) predicate.Session
- func ExpiresAtLT(v time.Time) predicate.Session
- func ExpiresAtLTE(v time.Time) predicate.Session
- func ExpiresAtNEQ(v time.Time) predicate.Session
- func ExpiresAtNotIn(vs ...time.Time) predicate.Session
- func HasUser() predicate.Session
- func HasUserWith(preds ...predicate.Users) predicate.Session
- func ID(id uuid.UUID) predicate.Session
- func IDEQ(id uuid.UUID) predicate.Session
- func IDGT(id uuid.UUID) predicate.Session
- func IDGTE(id uuid.UUID) predicate.Session
- func IDIn(ids ...uuid.UUID) predicate.Session
- func IDLT(id uuid.UUID) predicate.Session
- func IDLTE(id uuid.UUID) predicate.Session
- func IDNEQ(id uuid.UUID) predicate.Session
- func IDNotIn(ids ...uuid.UUID) predicate.Session
- func Not(p predicate.Session) predicate.Session
- func Or(predicates ...predicate.Session) predicate.Session
- func SessionToken(v string) predicate.Session
- func SessionTokenContains(v string) predicate.Session
- func SessionTokenContainsFold(v string) predicate.Session
- func SessionTokenEQ(v string) predicate.Session
- func SessionTokenEqualFold(v string) predicate.Session
- func SessionTokenGT(v string) predicate.Session
- func SessionTokenGTE(v string) predicate.Session
- func SessionTokenHasPrefix(v string) predicate.Session
- func SessionTokenHasSuffix(v string) predicate.Session
- func SessionTokenIn(vs ...string) predicate.Session
- func SessionTokenLT(v string) predicate.Session
- func SessionTokenLTE(v string) predicate.Session
- func SessionTokenNEQ(v string) predicate.Session
- func SessionTokenNotIn(vs ...string) predicate.Session
- func UpdatedAt(v time.Time) predicate.Session
- func UpdatedAtEQ(v time.Time) predicate.Session
- func UpdatedAtGT(v time.Time) predicate.Session
- func UpdatedAtGTE(v time.Time) predicate.Session
- func UpdatedAtIn(vs ...time.Time) predicate.Session
- func UpdatedAtLT(v time.Time) predicate.Session
- func UpdatedAtLTE(v time.Time) predicate.Session
- func UpdatedAtNEQ(v time.Time) predicate.Session
- func UpdatedAtNotIn(vs ...time.Time) predicate.Session
- func UserID(v uuid.UUID) predicate.Session
- func UserIDEQ(v uuid.UUID) predicate.Session
- func UserIDIn(vs ...uuid.UUID) predicate.Session
- func UserIDNEQ(v uuid.UUID) predicate.Session
- func UserIDNotIn(vs ...uuid.UUID) predicate.Session
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeleted(opts ...sql.OrderTermOption) OrderOption
- func ByExpiresAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func BySessionToken(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByUserID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the session type in the database. Label = "session" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldSessionToken holds the string denoting the session_token field in the database. FieldSessionToken = "session_token" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldExpiresAt holds the string denoting the expires_at field in the database. FieldExpiresAt = "expires_at" // FieldDeleted holds the string denoting the deleted field in the database. FieldDeleted = "deleted" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeUser holds the string denoting the user edge name in mutations. EdgeUser = "user" // Table holds the table name of the session in the database. Table = "sessions" // UserTable is the table that holds the user relation/edge. UserTable = "sessions" // UserInverseTable is the table name for the Users entity. // It exists in this package in order to avoid circular dependency with the "users" package. UserInverseTable = "users" // UserColumn is the table column denoting the user relation/edge. UserColumn = "user_id" )
Variables ¶
var ( // DefaultDeleted holds the default value on creation for the "deleted" field. DefaultDeleted bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldSessionToken, FieldUserID, FieldExpiresAt, FieldDeleted, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for session fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Deleted ¶
Deleted applies equality check predicate on the "deleted" field. It's identical to DeletedEQ.
func DeletedNEQ ¶
DeletedNEQ applies the NEQ predicate on the "deleted" field.
func ExpiresAt ¶
ExpiresAt applies equality check predicate on the "expires_at" field. It's identical to ExpiresAtEQ.
func ExpiresAtEQ ¶
ExpiresAtEQ applies the EQ predicate on the "expires_at" field.
func ExpiresAtGT ¶
ExpiresAtGT applies the GT predicate on the "expires_at" field.
func ExpiresAtGTE ¶
ExpiresAtGTE applies the GTE predicate on the "expires_at" field.
func ExpiresAtIn ¶
ExpiresAtIn applies the In predicate on the "expires_at" field.
func ExpiresAtLT ¶
ExpiresAtLT applies the LT predicate on the "expires_at" field.
func ExpiresAtLTE ¶
ExpiresAtLTE applies the LTE predicate on the "expires_at" field.
func ExpiresAtNEQ ¶
ExpiresAtNEQ applies the NEQ predicate on the "expires_at" field.
func ExpiresAtNotIn ¶
ExpiresAtNotIn applies the NotIn predicate on the "expires_at" field.
func HasUserWith ¶
HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).
func SessionToken ¶
SessionToken applies equality check predicate on the "session_token" field. It's identical to SessionTokenEQ.
func SessionTokenContains ¶
SessionTokenContains applies the Contains predicate on the "session_token" field.
func SessionTokenContainsFold ¶
SessionTokenContainsFold applies the ContainsFold predicate on the "session_token" field.
func SessionTokenEQ ¶
SessionTokenEQ applies the EQ predicate on the "session_token" field.
func SessionTokenEqualFold ¶
SessionTokenEqualFold applies the EqualFold predicate on the "session_token" field.
func SessionTokenGT ¶
SessionTokenGT applies the GT predicate on the "session_token" field.
func SessionTokenGTE ¶
SessionTokenGTE applies the GTE predicate on the "session_token" field.
func SessionTokenHasPrefix ¶
SessionTokenHasPrefix applies the HasPrefix predicate on the "session_token" field.
func SessionTokenHasSuffix ¶
SessionTokenHasSuffix applies the HasSuffix predicate on the "session_token" field.
func SessionTokenIn ¶
SessionTokenIn applies the In predicate on the "session_token" field.
func SessionTokenLT ¶
SessionTokenLT applies the LT predicate on the "session_token" field.
func SessionTokenLTE ¶
SessionTokenLTE applies the LTE predicate on the "session_token" field.
func SessionTokenNEQ ¶
SessionTokenNEQ applies the NEQ predicate on the "session_token" field.
func SessionTokenNotIn ¶
SessionTokenNotIn applies the NotIn predicate on the "session_token" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UserID ¶
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDNotIn ¶
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Session queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDeleted ¶
func ByDeleted(opts ...sql.OrderTermOption) OrderOption
ByDeleted orders the results by the deleted field.
func ByExpiresAt ¶
func ByExpiresAt(opts ...sql.OrderTermOption) OrderOption
ByExpiresAt orders the results by the expires_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func BySessionToken ¶
func BySessionToken(opts ...sql.OrderTermOption) OrderOption
BySessionToken orders the results by the session_token field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUserField ¶
func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
ByUserField orders the results by user field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.