Documentation
¶
Index ¶
- Constants
- Variables
- func AccessToken(v string) predicate.Users
- func AccessTokenContains(v string) predicate.Users
- func AccessTokenContainsFold(v string) predicate.Users
- func AccessTokenEQ(v string) predicate.Users
- func AccessTokenEqualFold(v string) predicate.Users
- func AccessTokenGT(v string) predicate.Users
- func AccessTokenGTE(v string) predicate.Users
- func AccessTokenHasPrefix(v string) predicate.Users
- func AccessTokenHasSuffix(v string) predicate.Users
- func AccessTokenIn(vs ...string) predicate.Users
- func AccessTokenIsNil() predicate.Users
- func AccessTokenLT(v string) predicate.Users
- func AccessTokenLTE(v string) predicate.Users
- func AccessTokenNEQ(v string) predicate.Users
- func AccessTokenNotIn(vs ...string) predicate.Users
- func AccessTokenNotNil() predicate.Users
- func And(predicates ...predicate.Users) predicate.Users
- func Avatar(v string) predicate.Users
- func AvatarContains(v string) predicate.Users
- func AvatarContainsFold(v string) predicate.Users
- func AvatarEQ(v string) predicate.Users
- func AvatarEqualFold(v string) predicate.Users
- func AvatarGT(v string) predicate.Users
- func AvatarGTE(v string) predicate.Users
- func AvatarHasPrefix(v string) predicate.Users
- func AvatarHasSuffix(v string) predicate.Users
- func AvatarIn(vs ...string) predicate.Users
- func AvatarIsNil() predicate.Users
- func AvatarLT(v string) predicate.Users
- func AvatarLTE(v string) predicate.Users
- func AvatarNEQ(v string) predicate.Users
- func AvatarNotIn(vs ...string) predicate.Users
- func AvatarNotNil() predicate.Users
- func CreatedAt(v time.Time) predicate.Users
- func CreatedAtEQ(v time.Time) predicate.Users
- func CreatedAtGT(v time.Time) predicate.Users
- func CreatedAtGTE(v time.Time) predicate.Users
- func CreatedAtIn(vs ...time.Time) predicate.Users
- func CreatedAtLT(v time.Time) predicate.Users
- func CreatedAtLTE(v time.Time) predicate.Users
- func CreatedAtNEQ(v time.Time) predicate.Users
- func CreatedAtNotIn(vs ...time.Time) predicate.Users
- func Deleted(v bool) predicate.Users
- func DeletedEQ(v bool) predicate.Users
- func DeletedNEQ(v bool) predicate.Users
- func Description(v string) predicate.Users
- func DescriptionContains(v string) predicate.Users
- func DescriptionContainsFold(v string) predicate.Users
- func DescriptionEQ(v string) predicate.Users
- func DescriptionEqualFold(v string) predicate.Users
- func DescriptionGT(v string) predicate.Users
- func DescriptionGTE(v string) predicate.Users
- func DescriptionHasPrefix(v string) predicate.Users
- func DescriptionHasSuffix(v string) predicate.Users
- func DescriptionIn(vs ...string) predicate.Users
- func DescriptionIsNil() predicate.Users
- func DescriptionLT(v string) predicate.Users
- func DescriptionLTE(v string) predicate.Users
- func DescriptionNEQ(v string) predicate.Users
- func DescriptionNotIn(vs ...string) predicate.Users
- func DescriptionNotNil() predicate.Users
- func ExpiresIn(v float64) predicate.Users
- func ExpiresInEQ(v float64) predicate.Users
- func ExpiresInGT(v float64) predicate.Users
- func ExpiresInGTE(v float64) predicate.Users
- func ExpiresInIn(vs ...float64) predicate.Users
- func ExpiresInIsNil() predicate.Users
- func ExpiresInLT(v float64) predicate.Users
- func ExpiresInLTE(v float64) predicate.Users
- func ExpiresInNEQ(v float64) predicate.Users
- func ExpiresInNotIn(vs ...float64) predicate.Users
- func ExpiresInNotNil() predicate.Users
- func ExternalID(v string) predicate.Users
- func ExternalIDContains(v string) predicate.Users
- func ExternalIDContainsFold(v string) predicate.Users
- func ExternalIDEQ(v string) predicate.Users
- func ExternalIDEqualFold(v string) predicate.Users
- func ExternalIDGT(v string) predicate.Users
- func ExternalIDGTE(v string) predicate.Users
- func ExternalIDHasPrefix(v string) predicate.Users
- func ExternalIDHasSuffix(v string) predicate.Users
- func ExternalIDIn(vs ...string) predicate.Users
- func ExternalIDLT(v string) predicate.Users
- func ExternalIDLTE(v string) predicate.Users
- func ExternalIDNEQ(v string) predicate.Users
- func ExternalIDNotIn(vs ...string) predicate.Users
- func GlobalName(v string) predicate.Users
- func GlobalNameContains(v string) predicate.Users
- func GlobalNameContainsFold(v string) predicate.Users
- func GlobalNameEQ(v string) predicate.Users
- func GlobalNameEqualFold(v string) predicate.Users
- func GlobalNameGT(v string) predicate.Users
- func GlobalNameGTE(v string) predicate.Users
- func GlobalNameHasPrefix(v string) predicate.Users
- func GlobalNameHasSuffix(v string) predicate.Users
- func GlobalNameIn(vs ...string) predicate.Users
- func GlobalNameLT(v string) predicate.Users
- func GlobalNameLTE(v string) predicate.Users
- func GlobalNameNEQ(v string) predicate.Users
- func GlobalNameNotIn(vs ...string) predicate.Users
- func HasUsersAccounts() predicate.Users
- func HasUsersAccountsWith(preds ...predicate.Account) predicate.Users
- func HasUsersLinks() predicate.Users
- func HasUsersLinksWith(preds ...predicate.Links) predicate.Users
- func HasUsersSessions() predicate.Users
- func HasUsersSessionsWith(preds ...predicate.Session) predicate.Users
- func ID(id uuid.UUID) predicate.Users
- func IDEQ(id uuid.UUID) predicate.Users
- func IDGT(id uuid.UUID) predicate.Users
- func IDGTE(id uuid.UUID) predicate.Users
- func IDIn(ids ...uuid.UUID) predicate.Users
- func IDLT(id uuid.UUID) predicate.Users
- func IDLTE(id uuid.UUID) predicate.Users
- func IDNEQ(id uuid.UUID) predicate.Users
- func IDNotIn(ids ...uuid.UUID) predicate.Users
- func Not(p predicate.Users) predicate.Users
- func Or(predicates ...predicate.Users) predicate.Users
- func RefreshToken(v string) predicate.Users
- func RefreshTokenContains(v string) predicate.Users
- func RefreshTokenContainsFold(v string) predicate.Users
- func RefreshTokenEQ(v string) predicate.Users
- func RefreshTokenEqualFold(v string) predicate.Users
- func RefreshTokenGT(v string) predicate.Users
- func RefreshTokenGTE(v string) predicate.Users
- func RefreshTokenHasPrefix(v string) predicate.Users
- func RefreshTokenHasSuffix(v string) predicate.Users
- func RefreshTokenIn(vs ...string) predicate.Users
- func RefreshTokenIsNil() predicate.Users
- func RefreshTokenLT(v string) predicate.Users
- func RefreshTokenLTE(v string) predicate.Users
- func RefreshTokenNEQ(v string) predicate.Users
- func RefreshTokenNotIn(vs ...string) predicate.Users
- func RefreshTokenNotNil() predicate.Users
- func Scope(v string) predicate.Users
- func ScopeContains(v string) predicate.Users
- func ScopeContainsFold(v string) predicate.Users
- func ScopeEQ(v string) predicate.Users
- func ScopeEqualFold(v string) predicate.Users
- func ScopeGT(v string) predicate.Users
- func ScopeGTE(v string) predicate.Users
- func ScopeHasPrefix(v string) predicate.Users
- func ScopeHasSuffix(v string) predicate.Users
- func ScopeIn(vs ...string) predicate.Users
- func ScopeIsNil() predicate.Users
- func ScopeLT(v string) predicate.Users
- func ScopeLTE(v string) predicate.Users
- func ScopeNEQ(v string) predicate.Users
- func ScopeNotIn(vs ...string) predicate.Users
- func ScopeNotNil() predicate.Users
- func SessionState(v string) predicate.Users
- func SessionStateContains(v string) predicate.Users
- func SessionStateContainsFold(v string) predicate.Users
- func SessionStateEQ(v string) predicate.Users
- func SessionStateEqualFold(v string) predicate.Users
- func SessionStateGT(v string) predicate.Users
- func SessionStateGTE(v string) predicate.Users
- func SessionStateHasPrefix(v string) predicate.Users
- func SessionStateHasSuffix(v string) predicate.Users
- func SessionStateIn(vs ...string) predicate.Users
- func SessionStateIsNil() predicate.Users
- func SessionStateLT(v string) predicate.Users
- func SessionStateLTE(v string) predicate.Users
- func SessionStateNEQ(v string) predicate.Users
- func SessionStateNotIn(vs ...string) predicate.Users
- func SessionStateNotNil() predicate.Users
- func Slug(v string) predicate.Users
- func SlugContains(v string) predicate.Users
- func SlugContainsFold(v string) predicate.Users
- func SlugEQ(v string) predicate.Users
- func SlugEqualFold(v string) predicate.Users
- func SlugGT(v string) predicate.Users
- func SlugGTE(v string) predicate.Users
- func SlugHasPrefix(v string) predicate.Users
- func SlugHasSuffix(v string) predicate.Users
- func SlugIn(vs ...string) predicate.Users
- func SlugLT(v string) predicate.Users
- func SlugLTE(v string) predicate.Users
- func SlugNEQ(v string) predicate.Users
- func SlugNotIn(vs ...string) predicate.Users
- func UpdatedAt(v time.Time) predicate.Users
- func UpdatedAtEQ(v time.Time) predicate.Users
- func UpdatedAtGT(v time.Time) predicate.Users
- func UpdatedAtGTE(v time.Time) predicate.Users
- func UpdatedAtIn(vs ...time.Time) predicate.Users
- func UpdatedAtLT(v time.Time) predicate.Users
- func UpdatedAtLTE(v time.Time) predicate.Users
- func UpdatedAtNEQ(v time.Time) predicate.Users
- func UpdatedAtNotIn(vs ...time.Time) predicate.Users
- func Username(v string) predicate.Users
- func UsernameContains(v string) predicate.Users
- func UsernameContainsFold(v string) predicate.Users
- func UsernameEQ(v string) predicate.Users
- func UsernameEqualFold(v string) predicate.Users
- func UsernameGT(v string) predicate.Users
- func UsernameGTE(v string) predicate.Users
- func UsernameHasPrefix(v string) predicate.Users
- func UsernameHasSuffix(v string) predicate.Users
- func UsernameIn(vs ...string) predicate.Users
- func UsernameLT(v string) predicate.Users
- func UsernameLTE(v string) predicate.Users
- func UsernameNEQ(v string) predicate.Users
- func UsernameNotIn(vs ...string) predicate.Users
- func ValidColumn(column string) bool
- type OrderOption
- func ByAccessToken(opts ...sql.OrderTermOption) OrderOption
- func ByAvatar(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeleted(opts ...sql.OrderTermOption) OrderOption
- func ByDescription(opts ...sql.OrderTermOption) OrderOption
- func ByExpiresIn(opts ...sql.OrderTermOption) OrderOption
- func ByExternalID(opts ...sql.OrderTermOption) OrderOption
- func ByGlobalName(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByRefreshToken(opts ...sql.OrderTermOption) OrderOption
- func ByScope(opts ...sql.OrderTermOption) OrderOption
- func BySessionState(opts ...sql.OrderTermOption) OrderOption
- func BySlug(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUsername(opts ...sql.OrderTermOption) OrderOption
- func ByUsersAccounts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByUsersAccountsCount(opts ...sql.OrderTermOption) OrderOption
- func ByUsersLinks(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByUsersLinksCount(opts ...sql.OrderTermOption) OrderOption
- func ByUsersSessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByUsersSessionsCount(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the users type in the database. Label = "users" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldExternalID holds the string denoting the external_id field in the database. FieldExternalID = "external_id" // FieldUsername holds the string denoting the username field in the database. FieldUsername = "username" // FieldGlobalName holds the string denoting the global_name field in the database. FieldGlobalName = "global_name" // FieldSlug holds the string denoting the slug field in the database. FieldSlug = "slug" // FieldAvatar holds the string denoting the avatar field in the database. FieldAvatar = "avatar" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldAccessToken holds the string denoting the access_token field in the database. FieldAccessToken = "access_token" // FieldRefreshToken holds the string denoting the refresh_token field in the database. FieldRefreshToken = "refresh_token" // FieldScope holds the string denoting the scope field in the database. FieldScope = "scope" // FieldExpiresIn holds the string denoting the expires_in field in the database. FieldExpiresIn = "expires_in" // FieldSessionState holds the string denoting the session_state field in the database. FieldSessionState = "session_state" // FieldDeleted holds the string denoting the deleted field in the database. FieldDeleted = "deleted" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeUsersLinks holds the string denoting the users_links edge name in mutations. EdgeUsersLinks = "users_links" // EdgeUsersSessions holds the string denoting the users_sessions edge name in mutations. EdgeUsersSessions = "users_sessions" // EdgeUsersAccounts holds the string denoting the users_accounts edge name in mutations. EdgeUsersAccounts = "users_accounts" // Table holds the table name of the users in the database. Table = "users" // UsersLinksTable is the table that holds the users_links relation/edge. UsersLinksTable = "links" // UsersLinksInverseTable is the table name for the Links entity. // It exists in this package in order to avoid circular dependency with the "links" package. UsersLinksInverseTable = "links" // UsersLinksColumn is the table column denoting the users_links relation/edge. UsersLinksColumn = "user_id" // UsersSessionsTable is the table that holds the users_sessions relation/edge. UsersSessionsTable = "sessions" // UsersSessionsInverseTable is the table name for the Session entity. // It exists in this package in order to avoid circular dependency with the "session" package. UsersSessionsInverseTable = "sessions" // UsersSessionsColumn is the table column denoting the users_sessions relation/edge. UsersSessionsColumn = "user_id" // UsersAccountsTable is the table that holds the users_accounts relation/edge. UsersAccountsTable = "accounts" // UsersAccountsInverseTable is the table name for the Account entity. // It exists in this package in order to avoid circular dependency with the "account" package. UsersAccountsInverseTable = "accounts" // UsersAccountsColumn is the table column denoting the users_accounts relation/edge. UsersAccountsColumn = "external_id" )
Variables ¶
var ( // UsernameValidator is a validator for the "username" field. It is called by the builders before save. UsernameValidator func(string) error // GlobalNameValidator is a validator for the "global_name" field. It is called by the builders before save. GlobalNameValidator func(string) error // SlugValidator is a validator for the "slug" field. It is called by the builders before save. SlugValidator func(string) error // AvatarValidator is a validator for the "avatar" field. It is called by the builders before save. AvatarValidator func(string) error // DescriptionValidator is a validator for the "description" field. It is called by the builders before save. DescriptionValidator func(string) error // AccessTokenValidator is a validator for the "access_token" field. It is called by the builders before save. AccessTokenValidator func(string) error // RefreshTokenValidator is a validator for the "refresh_token" field. It is called by the builders before save. RefreshTokenValidator func(string) error // ScopeValidator is a validator for the "scope" field. It is called by the builders before save. ScopeValidator func(string) error // DefaultDeleted holds the default value on creation for the "deleted" field. DefaultDeleted bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldExternalID, FieldUsername, FieldGlobalName, FieldSlug, FieldAvatar, FieldDescription, FieldAccessToken, FieldRefreshToken, FieldScope, FieldExpiresIn, FieldSessionState, FieldDeleted, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for users fields.
Functions ¶
func AccessToken ¶
AccessToken applies equality check predicate on the "access_token" field. It's identical to AccessTokenEQ.
func AccessTokenContains ¶
AccessTokenContains applies the Contains predicate on the "access_token" field.
func AccessTokenContainsFold ¶
AccessTokenContainsFold applies the ContainsFold predicate on the "access_token" field.
func AccessTokenEQ ¶
AccessTokenEQ applies the EQ predicate on the "access_token" field.
func AccessTokenEqualFold ¶
AccessTokenEqualFold applies the EqualFold predicate on the "access_token" field.
func AccessTokenGT ¶
AccessTokenGT applies the GT predicate on the "access_token" field.
func AccessTokenGTE ¶
AccessTokenGTE applies the GTE predicate on the "access_token" field.
func AccessTokenHasPrefix ¶
AccessTokenHasPrefix applies the HasPrefix predicate on the "access_token" field.
func AccessTokenHasSuffix ¶
AccessTokenHasSuffix applies the HasSuffix predicate on the "access_token" field.
func AccessTokenIn ¶
AccessTokenIn applies the In predicate on the "access_token" field.
func AccessTokenIsNil ¶
AccessTokenIsNil applies the IsNil predicate on the "access_token" field.
func AccessTokenLT ¶
AccessTokenLT applies the LT predicate on the "access_token" field.
func AccessTokenLTE ¶
AccessTokenLTE applies the LTE predicate on the "access_token" field.
func AccessTokenNEQ ¶
AccessTokenNEQ applies the NEQ predicate on the "access_token" field.
func AccessTokenNotIn ¶
AccessTokenNotIn applies the NotIn predicate on the "access_token" field.
func AccessTokenNotNil ¶
AccessTokenNotNil applies the NotNil predicate on the "access_token" field.
func Avatar ¶
Avatar applies equality check predicate on the "avatar" field. It's identical to AvatarEQ.
func AvatarContains ¶
AvatarContains applies the Contains predicate on the "avatar" field.
func AvatarContainsFold ¶
AvatarContainsFold applies the ContainsFold predicate on the "avatar" field.
func AvatarEqualFold ¶
AvatarEqualFold applies the EqualFold predicate on the "avatar" field.
func AvatarHasPrefix ¶
AvatarHasPrefix applies the HasPrefix predicate on the "avatar" field.
func AvatarHasSuffix ¶
AvatarHasSuffix applies the HasSuffix predicate on the "avatar" field.
func AvatarIsNil ¶
AvatarIsNil applies the IsNil predicate on the "avatar" field.
func AvatarNotIn ¶
AvatarNotIn applies the NotIn predicate on the "avatar" field.
func AvatarNotNil ¶
AvatarNotNil applies the NotNil predicate on the "avatar" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Deleted ¶
Deleted applies equality check predicate on the "deleted" field. It's identical to DeletedEQ.
func DeletedNEQ ¶
DeletedNEQ applies the NEQ predicate on the "deleted" field.
func Description ¶
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
DescriptionIn applies the In predicate on the "description" field.
func DescriptionIsNil ¶
DescriptionIsNil applies the IsNil predicate on the "description" field.
func DescriptionLT ¶
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
DescriptionNotIn applies the NotIn predicate on the "description" field.
func DescriptionNotNil ¶
DescriptionNotNil applies the NotNil predicate on the "description" field.
func ExpiresIn ¶
ExpiresIn applies equality check predicate on the "expires_in" field. It's identical to ExpiresInEQ.
func ExpiresInEQ ¶
ExpiresInEQ applies the EQ predicate on the "expires_in" field.
func ExpiresInGT ¶
ExpiresInGT applies the GT predicate on the "expires_in" field.
func ExpiresInGTE ¶
ExpiresInGTE applies the GTE predicate on the "expires_in" field.
func ExpiresInIn ¶
ExpiresInIn applies the In predicate on the "expires_in" field.
func ExpiresInIsNil ¶
ExpiresInIsNil applies the IsNil predicate on the "expires_in" field.
func ExpiresInLT ¶
ExpiresInLT applies the LT predicate on the "expires_in" field.
func ExpiresInLTE ¶
ExpiresInLTE applies the LTE predicate on the "expires_in" field.
func ExpiresInNEQ ¶
ExpiresInNEQ applies the NEQ predicate on the "expires_in" field.
func ExpiresInNotIn ¶
ExpiresInNotIn applies the NotIn predicate on the "expires_in" field.
func ExpiresInNotNil ¶
ExpiresInNotNil applies the NotNil predicate on the "expires_in" field.
func ExternalID ¶
ExternalID applies equality check predicate on the "external_id" field. It's identical to ExternalIDEQ.
func ExternalIDContains ¶
ExternalIDContains applies the Contains predicate on the "external_id" field.
func ExternalIDContainsFold ¶
ExternalIDContainsFold applies the ContainsFold predicate on the "external_id" field.
func ExternalIDEQ ¶
ExternalIDEQ applies the EQ predicate on the "external_id" field.
func ExternalIDEqualFold ¶
ExternalIDEqualFold applies the EqualFold predicate on the "external_id" field.
func ExternalIDGT ¶
ExternalIDGT applies the GT predicate on the "external_id" field.
func ExternalIDGTE ¶
ExternalIDGTE applies the GTE predicate on the "external_id" field.
func ExternalIDHasPrefix ¶
ExternalIDHasPrefix applies the HasPrefix predicate on the "external_id" field.
func ExternalIDHasSuffix ¶
ExternalIDHasSuffix applies the HasSuffix predicate on the "external_id" field.
func ExternalIDIn ¶
ExternalIDIn applies the In predicate on the "external_id" field.
func ExternalIDLT ¶
ExternalIDLT applies the LT predicate on the "external_id" field.
func ExternalIDLTE ¶
ExternalIDLTE applies the LTE predicate on the "external_id" field.
func ExternalIDNEQ ¶
ExternalIDNEQ applies the NEQ predicate on the "external_id" field.
func ExternalIDNotIn ¶
ExternalIDNotIn applies the NotIn predicate on the "external_id" field.
func GlobalName ¶
GlobalName applies equality check predicate on the "global_name" field. It's identical to GlobalNameEQ.
func GlobalNameContains ¶
GlobalNameContains applies the Contains predicate on the "global_name" field.
func GlobalNameContainsFold ¶
GlobalNameContainsFold applies the ContainsFold predicate on the "global_name" field.
func GlobalNameEQ ¶
GlobalNameEQ applies the EQ predicate on the "global_name" field.
func GlobalNameEqualFold ¶
GlobalNameEqualFold applies the EqualFold predicate on the "global_name" field.
func GlobalNameGT ¶
GlobalNameGT applies the GT predicate on the "global_name" field.
func GlobalNameGTE ¶
GlobalNameGTE applies the GTE predicate on the "global_name" field.
func GlobalNameHasPrefix ¶
GlobalNameHasPrefix applies the HasPrefix predicate on the "global_name" field.
func GlobalNameHasSuffix ¶
GlobalNameHasSuffix applies the HasSuffix predicate on the "global_name" field.
func GlobalNameIn ¶
GlobalNameIn applies the In predicate on the "global_name" field.
func GlobalNameLT ¶
GlobalNameLT applies the LT predicate on the "global_name" field.
func GlobalNameLTE ¶
GlobalNameLTE applies the LTE predicate on the "global_name" field.
func GlobalNameNEQ ¶
GlobalNameNEQ applies the NEQ predicate on the "global_name" field.
func GlobalNameNotIn ¶
GlobalNameNotIn applies the NotIn predicate on the "global_name" field.
func HasUsersAccounts ¶
HasUsersAccounts applies the HasEdge predicate on the "users_accounts" edge.
func HasUsersAccountsWith ¶
HasUsersAccountsWith applies the HasEdge predicate on the "users_accounts" edge with a given conditions (other predicates).
func HasUsersLinks ¶
HasUsersLinks applies the HasEdge predicate on the "users_links" edge.
func HasUsersLinksWith ¶
HasUsersLinksWith applies the HasEdge predicate on the "users_links" edge with a given conditions (other predicates).
func HasUsersSessions ¶
HasUsersSessions applies the HasEdge predicate on the "users_sessions" edge.
func HasUsersSessionsWith ¶
HasUsersSessionsWith applies the HasEdge predicate on the "users_sessions" edge with a given conditions (other predicates).
func RefreshToken ¶
RefreshToken applies equality check predicate on the "refresh_token" field. It's identical to RefreshTokenEQ.
func RefreshTokenContains ¶
RefreshTokenContains applies the Contains predicate on the "refresh_token" field.
func RefreshTokenContainsFold ¶
RefreshTokenContainsFold applies the ContainsFold predicate on the "refresh_token" field.
func RefreshTokenEQ ¶
RefreshTokenEQ applies the EQ predicate on the "refresh_token" field.
func RefreshTokenEqualFold ¶
RefreshTokenEqualFold applies the EqualFold predicate on the "refresh_token" field.
func RefreshTokenGT ¶
RefreshTokenGT applies the GT predicate on the "refresh_token" field.
func RefreshTokenGTE ¶
RefreshTokenGTE applies the GTE predicate on the "refresh_token" field.
func RefreshTokenHasPrefix ¶
RefreshTokenHasPrefix applies the HasPrefix predicate on the "refresh_token" field.
func RefreshTokenHasSuffix ¶
RefreshTokenHasSuffix applies the HasSuffix predicate on the "refresh_token" field.
func RefreshTokenIn ¶
RefreshTokenIn applies the In predicate on the "refresh_token" field.
func RefreshTokenIsNil ¶
RefreshTokenIsNil applies the IsNil predicate on the "refresh_token" field.
func RefreshTokenLT ¶
RefreshTokenLT applies the LT predicate on the "refresh_token" field.
func RefreshTokenLTE ¶
RefreshTokenLTE applies the LTE predicate on the "refresh_token" field.
func RefreshTokenNEQ ¶
RefreshTokenNEQ applies the NEQ predicate on the "refresh_token" field.
func RefreshTokenNotIn ¶
RefreshTokenNotIn applies the NotIn predicate on the "refresh_token" field.
func RefreshTokenNotNil ¶
RefreshTokenNotNil applies the NotNil predicate on the "refresh_token" field.
func Scope ¶
Scope applies equality check predicate on the "scope" field. It's identical to ScopeEQ.
func ScopeContains ¶
ScopeContains applies the Contains predicate on the "scope" field.
func ScopeContainsFold ¶
ScopeContainsFold applies the ContainsFold predicate on the "scope" field.
func ScopeEqualFold ¶
ScopeEqualFold applies the EqualFold predicate on the "scope" field.
func ScopeHasPrefix ¶
ScopeHasPrefix applies the HasPrefix predicate on the "scope" field.
func ScopeHasSuffix ¶
ScopeHasSuffix applies the HasSuffix predicate on the "scope" field.
func ScopeIsNil ¶
ScopeIsNil applies the IsNil predicate on the "scope" field.
func ScopeNotIn ¶
ScopeNotIn applies the NotIn predicate on the "scope" field.
func ScopeNotNil ¶
ScopeNotNil applies the NotNil predicate on the "scope" field.
func SessionState ¶
SessionState applies equality check predicate on the "session_state" field. It's identical to SessionStateEQ.
func SessionStateContains ¶
SessionStateContains applies the Contains predicate on the "session_state" field.
func SessionStateContainsFold ¶
SessionStateContainsFold applies the ContainsFold predicate on the "session_state" field.
func SessionStateEQ ¶
SessionStateEQ applies the EQ predicate on the "session_state" field.
func SessionStateEqualFold ¶
SessionStateEqualFold applies the EqualFold predicate on the "session_state" field.
func SessionStateGT ¶
SessionStateGT applies the GT predicate on the "session_state" field.
func SessionStateGTE ¶
SessionStateGTE applies the GTE predicate on the "session_state" field.
func SessionStateHasPrefix ¶
SessionStateHasPrefix applies the HasPrefix predicate on the "session_state" field.
func SessionStateHasSuffix ¶
SessionStateHasSuffix applies the HasSuffix predicate on the "session_state" field.
func SessionStateIn ¶
SessionStateIn applies the In predicate on the "session_state" field.
func SessionStateIsNil ¶
SessionStateIsNil applies the IsNil predicate on the "session_state" field.
func SessionStateLT ¶
SessionStateLT applies the LT predicate on the "session_state" field.
func SessionStateLTE ¶
SessionStateLTE applies the LTE predicate on the "session_state" field.
func SessionStateNEQ ¶
SessionStateNEQ applies the NEQ predicate on the "session_state" field.
func SessionStateNotIn ¶
SessionStateNotIn applies the NotIn predicate on the "session_state" field.
func SessionStateNotNil ¶
SessionStateNotNil applies the NotNil predicate on the "session_state" field.
func SlugContains ¶
SlugContains applies the Contains predicate on the "slug" field.
func SlugContainsFold ¶
SlugContainsFold applies the ContainsFold predicate on the "slug" field.
func SlugEqualFold ¶
SlugEqualFold applies the EqualFold predicate on the "slug" field.
func SlugHasPrefix ¶
SlugHasPrefix applies the HasPrefix predicate on the "slug" field.
func SlugHasSuffix ¶
SlugHasSuffix applies the HasSuffix predicate on the "slug" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func Username ¶
Username applies equality check predicate on the "username" field. It's identical to UsernameEQ.
func UsernameContains ¶
UsernameContains applies the Contains predicate on the "username" field.
func UsernameContainsFold ¶
UsernameContainsFold applies the ContainsFold predicate on the "username" field.
func UsernameEQ ¶
UsernameEQ applies the EQ predicate on the "username" field.
func UsernameEqualFold ¶
UsernameEqualFold applies the EqualFold predicate on the "username" field.
func UsernameGT ¶
UsernameGT applies the GT predicate on the "username" field.
func UsernameGTE ¶
UsernameGTE applies the GTE predicate on the "username" field.
func UsernameHasPrefix ¶
UsernameHasPrefix applies the HasPrefix predicate on the "username" field.
func UsernameHasSuffix ¶
UsernameHasSuffix applies the HasSuffix predicate on the "username" field.
func UsernameIn ¶
UsernameIn applies the In predicate on the "username" field.
func UsernameLT ¶
UsernameLT applies the LT predicate on the "username" field.
func UsernameLTE ¶
UsernameLTE applies the LTE predicate on the "username" field.
func UsernameNEQ ¶
UsernameNEQ applies the NEQ predicate on the "username" field.
func UsernameNotIn ¶
UsernameNotIn applies the NotIn predicate on the "username" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Users queries.
func ByAccessToken ¶
func ByAccessToken(opts ...sql.OrderTermOption) OrderOption
ByAccessToken orders the results by the access_token field.
func ByAvatar ¶
func ByAvatar(opts ...sql.OrderTermOption) OrderOption
ByAvatar orders the results by the avatar field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDeleted ¶
func ByDeleted(opts ...sql.OrderTermOption) OrderOption
ByDeleted orders the results by the deleted field.
func ByDescription ¶
func ByDescription(opts ...sql.OrderTermOption) OrderOption
ByDescription orders the results by the description field.
func ByExpiresIn ¶
func ByExpiresIn(opts ...sql.OrderTermOption) OrderOption
ByExpiresIn orders the results by the expires_in field.
func ByExternalID ¶
func ByExternalID(opts ...sql.OrderTermOption) OrderOption
ByExternalID orders the results by the external_id field.
func ByGlobalName ¶
func ByGlobalName(opts ...sql.OrderTermOption) OrderOption
ByGlobalName orders the results by the global_name field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByRefreshToken ¶
func ByRefreshToken(opts ...sql.OrderTermOption) OrderOption
ByRefreshToken orders the results by the refresh_token field.
func ByScope ¶
func ByScope(opts ...sql.OrderTermOption) OrderOption
ByScope orders the results by the scope field.
func BySessionState ¶
func BySessionState(opts ...sql.OrderTermOption) OrderOption
BySessionState orders the results by the session_state field.
func BySlug ¶
func BySlug(opts ...sql.OrderTermOption) OrderOption
BySlug orders the results by the slug field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUsername ¶
func ByUsername(opts ...sql.OrderTermOption) OrderOption
ByUsername orders the results by the username field.
func ByUsersAccounts ¶
func ByUsersAccounts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByUsersAccounts orders the results by users_accounts terms.
func ByUsersAccountsCount ¶
func ByUsersAccountsCount(opts ...sql.OrderTermOption) OrderOption
ByUsersAccountsCount orders the results by users_accounts count.
func ByUsersLinks ¶
func ByUsersLinks(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByUsersLinks orders the results by users_links terms.
func ByUsersLinksCount ¶
func ByUsersLinksCount(opts ...sql.OrderTermOption) OrderOption
ByUsersLinksCount orders the results by users_links count.
func ByUsersSessions ¶
func ByUsersSessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByUsersSessions orders the results by users_sessions terms.
func ByUsersSessionsCount ¶
func ByUsersSessionsCount(opts ...sql.OrderTermOption) OrderOption
ByUsersSessionsCount orders the results by users_sessions count.